@@ -3,7 +3,7 @@ use strict;
 use feature 'say';
 
 use RPi::WiringPi;
-use RPi::WiringPi::Constant qw(:all);
+use RPi::Const qw(:all);
 
 my ($dac_cs_pin, $adc_cs_pin) = (12, 26);
 my $adc_shiftreg_in = 2;
